@@ -1,8 +1,8 @@
-use strict;
-use warnings;
-package Dist::Zilla::App::Command::clean 6.017;
+package Dist::Zilla::App::Command::clean 6.032;
 # ABSTRACT: clean up after build, test, or install
 
+use Dist::Zilla::Pragmas;
+
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -50,7 +50,7 @@ Dist::Zilla::App::Command::clean - clean up after build, test, or install
 
 =head1 VERSION
 
-version 6.017
+version 6.032
 
 =head1 SYNOPSIS
 
@@ -61,6 +61,19 @@ install.  It's a very thin layer over the C<L<clean|Dist::Zilla/clean>> method
 on the Dist::Zilla object.  The documentation for that method gives more
 information about the files that will be removed.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl
+released in the last two to three years.  (That is, if the most recently
+released version is v5.40, then this module should work on both v5.40 and
+v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 OPTIONS
 
 =head2 -n, --dry-run
@@ -69,11 +82,11 @@ Nothing is removed; instead, everything that would be removed will be listed.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2024 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
