@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::AutoVersion 6.010;
+package Dist::Zilla::Plugin::AutoVersion 6.032;
 # ABSTRACT: take care of numbering versions so you don't have to
 
 use Moose;
@@ -7,6 +7,8 @@ with(
   'Dist::Zilla::Role::TextTemplate',
 );
 
+use Dist::Zilla::Pragmas;
+
 use namespace::autoclean;
 
 #pod =head1 DESCRIPTION
@@ -67,6 +69,11 @@ has format => (
 sub provide_version {
   my ($self) = @_;
 
+  if (exists $ENV{V}) {
+    $self->log_debug([ 'providing version %s', $ENV{V} ]);
+    return $ENV{V};
+  }
+
   # TODO declare this as a 'develop' prereq as we want it in
   # `dzil listdeps --author`
   require DateTime;
@@ -122,13 +129,26 @@ Dist::Zilla::Plugin::AutoVersion - take care of numbering versions so you don't
 
 =head1 VERSION
 
-version 6.010
+version 6.032
 
 =head1 DESCRIPTION
 
 This plugin automatically produces a version string, generally based on the
 current time.  By default, it will be in the format: 1.yyDDDn
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl
+released in the last two to three years.  (That is, if the most recently
+released version is v5.40, then this module should work on both v5.40 and
+v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 major
@@ -165,11 +185,11 @@ L<TextTemplate|Dist::Zilla::Role::TextTemplate>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ricardo SIGNES.
+This software is copyright (c) 2024 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
