@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::FileFinder::Filter 6.008;
+package Dist::Zilla::Plugin::FileFinder::Filter 6.032;
 # ABSTRACT: filter matches from other FileFinders
 
 use Moose;
@@ -9,6 +9,8 @@ with(
   },
 );
 
+use Dist::Zilla::Pragmas;
+
 use namespace::autoclean;
 
 #pod =head1 SYNOPSIS
@@ -103,7 +105,7 @@ Dist::Zilla::Plugin::FileFinder::Filter - filter matches from other FileFinders
 
 =head1 VERSION
 
-version 6.008
+version 6.032
 
 =head1 SYNOPSIS
 
@@ -123,6 +125,19 @@ You specify one or more FileFinders to generate the initial list of
 files.  Any file whose pathname matches any of the C<skip> regexs is
 removed from that list.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl
+released in the last two to three years.  (That is, if the most recently
+released version is v5.40, then this module should work on both v5.40 and
+v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 finder
@@ -145,11 +160,11 @@ find_files
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2024 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
